/* create.c
 *
 * Copyright 2018 Bruce Cowan <bruce@bcowan.me.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#define _GNU_SOURCE

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "array.h"

static int ret = 0;

static Array *
create_test_array (size_t start,
                   size_t end)
{
    Array *array = array_new (free);

    for (size_t i = start; i < end; i++)
    {
        char *str;
        if (asprintf (&str, "String #%zu", i) < 0)
            ret++;
        array_add (array, str);
    }

    return array;
}

static void
check_array (Array *array,
             size_t start,
             size_t end)
{
    for (size_t i = start, idx = 0; i < end; i++, idx++)
    {
        char *compare;

        const char *element = (const char *) array_get (array, idx);
        asprintf (&compare, "String #%zu", i);
        if (strcmp (element, compare))
        {
            fprintf (stderr, "check_array () failed\n");
            fprintf (stderr, "Expected %s, got %s\n",
                     compare, element);

            ret++;
        }

        free (compare);
    }
}

int
main (void)
{
    Array *array;

    array = create_test_array (0, 100);
    check_array (array, 0, 100);

    return ret;
}
